@@ -2,14 +2,15 @@
 
 #pragma once
 
-#include "zeek/analyzer/protocol/tcp/TCP.h"
-
 #include "zeek/analyzer/protocol/ntlm/events.bif.h"
 #include "zeek/analyzer/protocol/ntlm/ntlm_pac.h"
+#include "zeek/analyzer/protocol/tcp/TCP.h"
 
-namespace zeek::analyzer::ntlm {
+namespace zeek::analyzer::ntlm
+	{
 
-class NTLM_Analyzer final : public analyzer::tcp::TCP_ApplicationAnalyzer {
+class NTLM_Analyzer final : public analyzer::tcp::TCP_ApplicationAnalyzer
+	{
 
 public:
 	explicit NTLM_Analyzer(Connection* conn);
@@ -24,11 +25,10 @@ public:
 	// Overriden from analyzer::tcp::TCP_ApplicationAnalyzer.
 	void EndpointEOF(bool is_orig) override;
 
-	static analyzer::Analyzer* Instantiate(Connection* conn)
-		{ return new NTLM_Analyzer(conn); }
+	static analyzer::Analyzer* Instantiate(Connection* conn) { return new NTLM_Analyzer(conn); }
 
 protected:
 	binpac::NTLM::NTLM_Conn* interp;
-};
+	};
 
-} // namespace zeek::analyzer::ntlm
+	} // namespace zeek::analyzer::ntlm
